// #Fragment

	/**
	 * Pass Request to RESTful web service
	 *
	 * @param message
	 * @return
	 * @throws ActionProcessingException
	 */
	public Message process(Message message) throws ActionProcessingException {
		try {
		   	HttpRequest requestInfo = HttpRequest.getRequest(message);

			if (logger.isInfoEnabled())
				logger.debug("process " + ReflectionHelper.dumpHttpRequest(requestInfo));

			if (requestInfo==null)
	  			throw new ActionProcessingException("Internal Error - no HttpRequest found");

			if (requestInfo.getQueryParams().containsKey("doc"))
				return processWADLDocRequest(message, null);

			if (requestInfo.getPathInfo()==null)
				throw new ActionProcessingException("No path found");

			String 	path = requestInfo.getPathInfo();
			if (path.toLowerCase().endsWith(".wadl"))
				return processWADLRequest(message);
			else if (path.toLowerCase().endsWith(".xsd"))
				return processXSDRequest(message, path);

			// Load the envelope
			String 	restfulrequest=(String)message.getBody().get();
			int 	index = path.lastIndexOf('/');
			String 	method = path.substring(index+1);

			if (logger.isDebugEnabled()) {
				logger.debug("endpointUrl: [" + endpointUrl + "]");
				logger.debug("method: [" + method + "]");
				logger.debug("restfulrequest: [" + restfulrequest + "]");
				logger.debug("requestInfo.getContentType(): [" + requestInfo.getContentType() + "]");
				logger.debug("MediaType.valueOf(requestInfo.getContentType()): " + MediaType.valueOf(requestInfo.getContentType()));
			}

			ClientResponse response = null;
			if (requestInfo.getMethod().toLowerCase().contentEquals("post")) {
				response = JerseyClientSingleton.post	(endpointUrl
														,MediaType.valueOf(requestInfo.getContentType())
														,method
														,restfulrequest
														);

			} else if (requestInfo.getMethod().toLowerCase().contentEquals("get")) {
				response = JerseyClientSingleton.get	(endpointUrl
														,requestInfo.getQueryParams()
														,method
														,restfulrequest
														);
			} else
				throw new ActionProcessingException("Unknown method: " + requestInfo.getMethod());

			if (logger.isDebugEnabled())
				logger.debug(ReflectionHelper.dumpObject("response", response));

			String entityResponse = response.getEntity(String.class);
			if (logger.isDebugEnabled()) {
				logger.debug("entityResponse: [" + entityResponse +"]");
				logger.debug("response.getType(): [" + response.getType() +"]");
			}

			HttpResponse httpResponse = new HttpResponse(response.getStatus());
			httpResponse.setContentType(response.getType().toString());
			message.getBody().add(entityResponse);
			httpResponse.setResponse(message);
  		}
  		catch(Exception e) {
  			logger.error("Rest error", e);
			HttpResponse httpResponse = new HttpResponse(HttpStatus.SC_INTERNAL_SERVER_ERROR);
			httpResponse.setContentType(MediaType.TEXT_HTML.toString());
			message.getBody().add(e.toString());
			httpResponse.setResponse(message);
		}
		return message;
	}

